Rails.application.routes.draw do

  if Rails.configuration.pressr.main_blog_id.nil?
    root 'blog#summary'
  else
    root 'post#index', blog_id: Rails.configuration.pressr.main_blog_id
  end

  get '/b/:blog_name' => 'post#index', as: :blog
  
  get '/b/:blog_name/post/new' => 'post#new', as: :new_post
  post '/b/:blog_name/post/new' => 'post#create', as: :posts

  get '/b/:blog_name/post/edit/:post_id' => 'post#edit', as: :edit_post
  post '/b/:blog_name/post/edit/:post_id' => 'post#update'
  
  get '/b/:blog_name/post/:post_id' => 'post#get', as: :post
  
  get '/dashboard' => 'user#dashboard'
  get '/dashboard/user' => 'user#edit', as: :edit_user
  patch '/dashboard/user' => 'user#update', as: :update_user
  patch '/dashboard/update_password' => 'user#change_password', as: :change_password

  get '/b/:blog_name/edit' => 'blog#edit', as: :edit_blog
  get '/dashboard/b/create' => 'blog#edit', as: :new_blog
  post '/dashboard/b/create' => 'blog#update', as: :blogs
  patch '/b/:blog_id' => 'blog#update', as: :update_blog
  
  get '/signup' => 'user#new'
  post '/users' => 'user#create'
  
  get '/login' => 'sessions#new'
  post '/login' => 'sessions#create'

  post '/logout' => 'sessions#destroy'

  post '/dashboard/i/create' => 'user#upload_image', as: :upload_image
  post '/dashboard/v/create' => 'user#upload_video', as: :upload_video

  # Pages
  get '/b/:blog_name/p/:id/:path' => 'page#get', as: :page
  get '/b/:blog_name/p/:id/:path/edit' => 'page#edit', as: :edit_page
  patch '/b/:blog_name/p/:id/:path/edit' => 'page#update'
  delete '/b/:blog_name/p/:id/:path/edit' => 'page#delete', as: :delete_page
  get '/b/:blog_name/pages' => 'page#manage', as: :manage_page
  get '/b/:blog_name/pages/new' => 'page#new', as: :new_page
  post '/b/:blog_name/pages/new' => 'page#create'
  post '/b/:blog_name/pages/:p/priority/:dir' => 'page#priority', as: :page_priority

  # Categories
  get '/b/:blog_name/c/:cat_name' => 'category#get', as: :category
  get '/b/:blog_name/categories' => 'category#manage', as: :manage_category
  post '/b/:blog_name/categories' => 'category#create'
  delete '/b/:blog_name/c/:cat_name' => 'category#delete', as: :delete_category
  patch '/b/:blog_name/c/:cat_name' => 'category#update', as: :update_category

  # Comments
  post '/b/:blog_name/post/:post_id/comment' => 'comment#create', as: :comment
  delete '/comment/:id' => 'comment#delete', as: :delete_comment

  # Search
  get 'search' => 'blog#search', as: :search

  # Admin
  get '/admin/dashboard' => 'user#admin_dash', as: :admin_dashboard

  get '/u/:uname' => 'user#summary', as: :user
end
